@@ -2,7 +2,7 @@
 # Copyright (c) nexB Inc. and others. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
 # See http://www.apache.org/licenses/LICENSE-2.0 for the license text.
-# See https://github.com/nexB/license-expression for support or download.
+# See https://github.com/aboutcode-org/license-expression for support or download.
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 """
@@ -141,23 +141,24 @@ class ExpressionInfo:
     Licensing.validate().
 
     The ExpressionInfo class has the following fields:
+
     - original_expression: str.
-      - This is the license expression that was originally passed into
-        Licensing.validate()
+        - This is the license expression that was originally passed into
+          Licensing.validate()
 
     - normalized_expression: str.
-      - If a valid license expression has been passed into `validate()`,
-        then the license expression string will be set in this field.
+        - If a valid license expression has been passed into `validate()`,
+          then the license expression string will be set in this field.
 
     - errors: list
-      - If there were errors validating a license expression,
-        the error messages will be appended here.
+        - If there were errors validating a license expression,
+          the error messages will be appended here.
 
     - invalid_symbols: list
-      - If the license expression that has been passed into `validate()` has
-        license keys that are invalid (either that they are unknown or not used
-        in the right context), or the syntax is incorrect because an invalid
-        symbol was used, then those symbols will be appended here.
+        - If the license expression that has been passed into `validate()` has
+          license keys that are invalid (either that they are unknown or not used
+          in the right context), or the syntax is incorrect because an invalid
+          symbol was used, then those symbols will be appended here.
     """
 
     def __init__(
@@ -1652,6 +1653,7 @@ def validate_symbols(symbols, validate_keys=False):
       there were no warnings).
     - `errors` is a list of validation error messages (possibly empty if there
       were no errors).
+
     Keys and aliases are cleaned and validated for uniqueness.
 
     If ``validate_keys`` also validate that license keys are known keys.
@@ -1796,6 +1798,14 @@ def combine_expressions(
         'gpl AND mit AND apache'
         >>> str(combine_expressions(('gpl', 'mit', 'apache',), relation='OR'))
         'gpl OR mit OR apache'
+        >>> str(combine_expressions(('gpl', 'mit', 'mit',)))
+        'gpl AND mit'
+        >>> str(combine_expressions(('mit WITH foo', 'gpl', 'mit',)))
+        'mit WITH foo AND gpl AND mit'
+        >>> str(combine_expressions(('gpl', 'mit', 'mit',), relation='OR', unique=False))
+        'gpl OR mit OR mit'
+        >>> str(combine_expressions(('mit', 'gpl', 'mit',)))
+        'mit AND gpl'
     """
     if not expressions:
         return
@@ -1805,11 +1815,16 @@ def combine_expressions(
             f'expressions should be a list or tuple and not: {type(expressions)}'
         )
 
-    # only del with LicenseExpression objects
+    if not relation or relation.upper() not in ('AND', 'OR',):
+        raise TypeError(f'relation should be one of AND, OR and not: {relation}')
+
+
+    # only deal with LicenseExpression objects
     expressions = [licensing.parse(le, simple=True) for le in expressions]
 
-    # Remove duplicate expressions
     if unique:
+        # Remove duplicate element in the expressions list
+        # and preserve original order
         expressions = list({str(x): x for x in expressions}.values())
 
     if len(expressions) == 1:
